@@ -1,6 +1,6 @@
 package Git::CPAN::Patch::Import;
 BEGIN {
-  $Git::CPAN::Patch::Import::VERSION = '0.5.0';
+  $Git::CPAN::Patch::Import::VERSION = '0.6.0';
 }
 
 use 5.10.0;
@@ -35,6 +35,7 @@ use BackPAN::Index;
 }
 
 our $BackPAN_URL = "http://backpan.perl.org/";
+our $PERL_GIT_URL = 'git://perl5.git.perl.org/perl.git';
 
 sub backpan_index {
     state $backpan = do {
@@ -364,6 +365,13 @@ sub main {
     my $name    = $module_obj->name;
     my $version = $module_obj->version;
     my $dist    = $module_obj->package;
+
+    if ( $module_obj->package_name eq 'perl' ) {
+        say "$name is a core modules, ",
+            "clone perl from $PERL_GIT_URL instead.";
+        exit;
+    }
+
     my $dist_name = join("-", $module_obj->package_name, $module_obj->package_version);
 
     my $prettyname = $name . ( " ($module)" x ( $name ne $module ) );
@@ -546,7 +554,7 @@ Git::CPAN::Patch::Import - The meat of git-cpan-import
 
 =head1 VERSION
 
-version 0.5.0
+version 0.6.0
 
 =head1 DESCRIPTION
 
